// src/index.ts
import { dirname, isAbsolute, join, resolve } from "path";
import { genDynamicImport, genImport } from "knitwork";
function AsyncComponentLoader() {
  const DYNAMIC_COMP_REGEX = /\.vue\?async$/;
  return {
    name: "vite-async-component",
    enforce: "pre",
    resolveId(id, importer) {
      if (DYNAMIC_COMP_REGEX.test(id) && importer) {
        id = !isAbsolute(id) ? join(dirname(importer), id) : id;
        return `\0${resolve(id)}`;
      }
      return null;
    },
    async load(id) {
      if (!DYNAMIC_COMP_REGEX.test(id))
        return;
      const path = id.replace("\0", "").split("?")[0];
      const imports = [
        genImport("vue", ["defineAsyncComponent"]),
        genDefineAsyncComponent("AsyncComponent", path),
        "export default AsyncComponent;"
      ];
      return imports.join("\n");
    }
  };
}
function genDefineAsyncComponent(variable, src) {
  return `const ${variable} = defineAsyncComponent(${genDynamicImport(src)});`;
}
var src_default = AsyncComponentLoader;
export {
  src_default as default
};
